@@ -1,15 +1,18 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: cryptohash
-version: 0.11.7
-id: cryptohash-0.11.7-d9e0f8e58e69d0717d29fde3802983d0
-key: crypt_Ay7vlBu1GAw8Rzz5EpWt3c
+version: 0.11.9
+id: cryptohash-0.11.9-66ecf9651f97183101697edd4149971c
+key: crypt_GEQ1t4Tm0IqFmYz8P9KrIn
 license: BSD3
 copyright: Vincent Hanquez <vincent@snarc.org>
 maintainer: Vincent Hanquez <vincent@snarc.org>
 homepage: http://github.com/vincenthz/hs-cryptohash
 synopsis: collection of crypto hashes, fast, pure and practical
 description:
+    DEPRECATED: this library is still fully functional, but please use cryptonite for new projects
+    and convert old one to use cryptonite. This is where things are at nowadays.
+    .
     A collection of crypto hashes, with a practical incremental and one-pass, pure APIs,
     with performance close to the fastest implementations available in other languages.
     .
@@ -48,18 +51,19 @@ exposed-modules:
     Crypto.Hash.RIPEMD160 Crypto.Hash.Skein256 Crypto.Hash.Skein512
     Crypto.Hash.Tiger Crypto.Hash.Whirlpool Crypto.MAC.HMAC
     Crypto.MAC.SHA3
-hidden-modules: Crypto.Hash.Utils Crypto.Hash.Utils.Cpu
-                Crypto.Hash.Internal
+hidden-modules: Crypto.Hash.Internal
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-0.11.7
-library-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-0.11.7
-data-dir: /usr/share/arm-linux-ghc-7.10.3/cryptohash-0.11.7
-hs-libraries: HScryptohash-0.11.7-Ay7vlBu1GAw8Rzz5EpWt3c
+import-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-0.11.9
+library-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-0.11.9
+data-dir: /usr/share/arm-linux-ghc-7.10.3/cryptohash-0.11.9
+hs-libraries: HScryptohash-0.11.9-GEQ1t4Tm0IqFmYz8P9KrIn
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
+    cryptonite-0.13-349d06636b05d6ecd7f57ca79abfe077
     ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
+    memory-0.11-3a745e41fe78387f608c420e9b455d25
 haddock-interfaces: /usr/share/doc/haskell-cryptohash/html/cryptohash.haddock
 haddock-html: /usr/share/doc/haskell-cryptohash/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
